summaryrefslogtreecommitdiffstats
path: root/src/include/sys/mmio.h
diff options
context:
space:
mode:
authorAndrew Geissler <andrewg@us.ibm.com>2016-07-26 14:21:15 -0500
committerWilliam G. Hoffa <wghoffa@us.ibm.com>2016-08-16 15:43:07 -0400
commit025298b52002867f1e3516ba9810fd4642262980 (patch)
tree70ef20aabd7e1bb0d727e7f94d72ac74e522e62d /src/include/sys/mmio.h
parent5d57720970f8c8ffcefee7bfa5f9ec24f141501d (diff)
downloadtalos-hostboot-025298b52002867f1e3516ba9810fd4642262980.tar.gz
talos-hostboot-025298b52002867f1e3516ba9810fd4642262980.zip
Updates for new scratch registers in P9
P9 moves us from 8 scratch registers to 4. This commit handles this change and also adds the base support for partial cache. Change-Id: Ibe050c663744285dd3e77850649236a669dadbd6 RTC: 150923 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/27462 Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com> Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Martin Gloff <mgloff@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: William G. Hoffa <wghoffa@us.ibm.com>
Diffstat (limited to 'src/include/sys/mmio.h')
-rw-r--r--src/include/sys/mmio.h26
1 files changed, 8 insertions, 18 deletions
diff --git a/src/include/sys/mmio.h b/src/include/sys/mmio.h
index 4de734266..470c74e48 100644
--- a/src/include/sys/mmio.h
+++ b/src/include/sys/mmio.h
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2010,2014 */
+/* Contributors Listed Below - COPYRIGHT 2010,2016 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -88,25 +88,15 @@ void mmio_hmer_write(uint64_t value);
*/
enum MMIO_Scratch_Register
{
- /** Thread0 Scratch Register - Progress Code / Status. */
+ /** Progress Code / Status. */
MMIO_SCRATCH_PROGRESS_CODE = 0x0,
- /** Thread1 Scratch Register - PNOR mode control*/
- MMIO_SCRATCH_PNOR_MODE = 0x8,
- /** Thread2 Scratch Register - Unused */
- MMIO_SCRATCH_ISTEP_MODE = 0x10,
- /** Thread3 Scratch Register - Identifies if Hostboot is active after
- * host_start_payload. */
+ /** Identifies where hostboot currently resides and how large the
+ * space is */
+ MMIO_SCRATCH_MEMORY_STATE = 0x08,
+ /** Spare scratch reg */
+ MMIO_SCRATCH_SPARE = 0x10,
+ /** Identifies if Hostboot is active after host_start_payload. */
MMIO_SCRATCH_HOSTBOOT_ACTIVE = 0x18,
- /** Thread4 Scratch Register - Unused */
- MMIO_SCRATCH_RSVD_T4 = 0x20,
- /** Thread5 Scratch Register - Unused (unit tests may modify) */
- MMIO_SCRATCH_RSVD_T5_TESTCASES = 0x28,
- /** Thread6 Scratch Register - Identifies where hostboot currently
- resides and how large the space is */
- MMIO_SCRATCH_MEMORY_STATE = 0x30,
- /** Thread7 Scratch Register - Set be SBE for reduced-threads support
- * for AVPs. */
- MMIO_SCRATCH_AVP_THREADS = 0x38,
};
/** @fn mmio_scratch_read()
OpenPOWER on IntegriCloud